@@ -153,16 +153,16 @@ class AddVisitor : public Visitor
 public:
     AddVisitor(T *r) : mResource(r) {}
 
-    bool visit(const Event::Ptr &e) Q_DECL_OVERRIDE {
+    bool visit(const Event::Ptr &e) override {
         return mResource->addEvent(e);
     }
-    bool visit(const Todo::Ptr &t) Q_DECL_OVERRIDE {
+    bool visit(const Todo::Ptr &t) override {
         return mResource->addTodo(t);
     }
-    bool visit(const Journal::Ptr &j) Q_DECL_OVERRIDE {
+    bool visit(const Journal::Ptr &j) override {
         return mResource->addJournal(j);
     }
-    bool visit(const FreeBusy::Ptr &) Q_DECL_OVERRIDE {
+    bool visit(const FreeBusy::Ptr &) override {
         return false;
     }
 
@@ -181,19 +181,19 @@ class DeleteVisitor : public Visitor
 public:
     DeleteVisitor(T *r) : mResource(r) {}
 
-    bool visit(const Event::Ptr &e) Q_DECL_OVERRIDE {
+    bool visit(const Event::Ptr &e) override {
         mResource->deleteEvent(e);
         return true;
     }
-    bool visit(const Todo::Ptr &t) Q_DECL_OVERRIDE {
+    bool visit(const Todo::Ptr &t) override {
         mResource->deleteTodo(t);
         return true;
     }
-    bool visit(const Journal::Ptr &j) Q_DECL_OVERRIDE {
+    bool visit(const Journal::Ptr &j) override {
         mResource->deleteJournal(j);
         return true;
     }
-    bool visit(const FreeBusy::Ptr &) Q_DECL_OVERRIDE {
+    bool visit(const FreeBusy::Ptr &) override {
         return false;
     }
 
@@ -270,7 +270,7 @@ KDateTime::Spec Calendar::Private::timeZoneIdSpec(const QString &timeZoneId,
     ICalTimeZone tz = mTimeZones->zone(timeZoneId);
     if (!tz.isValid()) {
         ICalTimeZoneSource tzsrc;
-        tz = tzsrc.parse(icaltimezone_get_builtin_timezone(timeZoneId.toLatin1()));
+        tz = tzsrc.parse(icaltimezone_get_builtin_timezone(timeZoneId.toLatin1().constData()));
         if (view) {
             mBuiltInViewTimeZone = tz;
         } else {
@@ -603,25 +603,25 @@ Event::List Calendar::sortEvents(const Event::List &eventList,
 
     case EventSortStartDate:
         if (sortDirection == SortDirectionAscending) {
-            qSort(eventListSorted.begin(), eventListSorted.end(), Events::startDateLessThan);
+            std::sort(eventListSorted.begin(), eventListSorted.end(), Events::startDateLessThan);
         } else {
-            qSort(eventListSorted.begin(), eventListSorted.end(), Events::startDateMoreThan);
+            std::sort(eventListSorted.begin(), eventListSorted.end(), Events::startDateMoreThan);
         }
         break;
 
     case EventSortEndDate:
         if (sortDirection == SortDirectionAscending) {
-            qSort(eventListSorted.begin(), eventListSorted.end(), Events::endDateLessThan);
+            std::sort(eventListSorted.begin(), eventListSorted.end(), Events::endDateLessThan);
         } else {
-            qSort(eventListSorted.begin(), eventListSorted.end(), Events::endDateMoreThan);
+            std::sort(eventListSorted.begin(), eventListSorted.end(), Events::endDateMoreThan);
         }
         break;
 
     case EventSortSummary:
         if (sortDirection == SortDirectionAscending) {
-            qSort(eventListSorted.begin(), eventListSorted.end(), Events::summaryLessThan);
+            std::sort(eventListSorted.begin(), eventListSorted.end(), Events::summaryLessThan);
         } else {
-            qSort(eventListSorted.begin(), eventListSorted.end(), Events::summaryMoreThan);
+            std::sort(eventListSorted.begin(), eventListSorted.end(), Events::summaryMoreThan);
         }
         break;
     }
@@ -885,49 +885,49 @@ Todo::List Calendar::sortTodos(const Todo::List &todoList,
 
     case TodoSortStartDate:
         if (sortDirection == SortDirectionAscending) {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::startDateLessThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::startDateLessThan);
         } else {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::startDateMoreThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::startDateMoreThan);
         }
         break;
 
     case TodoSortDueDate:
         if (sortDirection == SortDirectionAscending) {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::dueDateLessThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::dueDateLessThan);
         } else {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::dueDateMoreThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::dueDateMoreThan);
         }
         break;
 
     case TodoSortPriority:
         if (sortDirection == SortDirectionAscending) {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::priorityLessThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::priorityLessThan);
         } else {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::priorityMoreThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::priorityMoreThan);
         }
         break;
 
     case TodoSortPercentComplete:
         if (sortDirection == SortDirectionAscending) {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::percentLessThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::percentLessThan);
         } else {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::percentMoreThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::percentMoreThan);
         }
         break;
 
     case TodoSortSummary:
         if (sortDirection == SortDirectionAscending) {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::summaryLessThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::summaryLessThan);
         } else {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::summaryMoreThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::summaryMoreThan);
         }
         break;
 
     case TodoSortCreated:
         if (sortDirection == SortDirectionAscending) {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::createdLessThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::createdLessThan);
         } else {
-            qSort(todoListSorted.begin(), todoListSorted.end(), Todos::createdMoreThan);
+            std::sort(todoListSorted.begin(), todoListSorted.end(), Todos::createdMoreThan);
         }
         break;
     }
@@ -975,17 +975,17 @@ Journal::List Calendar::sortJournals(const Journal::List &journalList,
 
     case JournalSortDate:
         if (sortDirection == SortDirectionAscending) {
-            qSort(journalListSorted.begin(), journalListSorted.end(), Journals::dateLessThan);
+            std::sort(journalListSorted.begin(), journalListSorted.end(), Journals::dateLessThan);
         } else {
-            qSort(journalListSorted.begin(), journalListSorted.end(), Journals::dateMoreThan);
+            std::sort(journalListSorted.begin(), journalListSorted.end(), Journals::dateMoreThan);
         }
         break;
 
     case JournalSortSummary:
         if (sortDirection == SortDirectionAscending) {
-            qSort(journalListSorted.begin(), journalListSorted.end(), Journals::summaryLessThan);
+            std::sort(journalListSorted.begin(), journalListSorted.end(), Journals::summaryLessThan);
         } else {
-            qSort(journalListSorted.begin(), journalListSorted.end(), Journals::summaryMoreThan);
+            std::sort(journalListSorted.begin(), journalListSorted.end(), Journals::summaryMoreThan);
         }
         break;
     }
@@ -1112,9 +1112,9 @@ void Calendar::removeRelations(const Incidence::Ptr &incidence)
                 uidit != relatedToUids.constEnd(); ++uidit) {
             Incidence::List tempList;
             // Remove all to get access to the remaining entries
-            Incidence::List l = values(d->mOrphans, *uidit);
+            const Incidence::List l = values(d->mOrphans, *uidit);
             d->mOrphans.remove(*uidit);
-            foreach (const Incidence::Ptr &i, l) {
+            for (const Incidence::Ptr &i : l) {
                 if (i != incidence) {
                     tempList.append(i);
                 }
@@ -1229,7 +1229,7 @@ void Calendar::setModified(bool modified)
 {
     if (modified != d->mModified || d->mNewObserver) {
         d->mNewObserver = false;
-        foreach (CalendarObserver *observer, d->mObservers) {
+        for (CalendarObserver *observer : qAsConst(d->mObservers)) {
             observer->calendarModified(modified, this);
         }
         d->mModified = modified;
@@ -1285,7 +1285,7 @@ void Calendar::notifyIncidenceAdded(const Incidence::Ptr &incidence)
         return;
     }
 
-    foreach (CalendarObserver *observer, d->mObservers) {
+    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
         observer->calendarIncidenceAdded(incidence);
     }
 }
@@ -1300,7 +1300,7 @@ void Calendar::notifyIncidenceChanged(const Incidence::Ptr &incidence)
         return;
     }
 
-    foreach (CalendarObserver *observer, d->mObservers) {
+    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
         observer->calendarIncidenceChanged(incidence);
     }
 }
@@ -1315,7 +1315,7 @@ void Calendar::notifyIncidenceAboutToBeDeleted(const Incidence::Ptr &incidence)
         return;
     }
 
-    foreach (CalendarObserver *observer, d->mObservers) {
+    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
         observer->calendarIncidenceAboutToBeDeleted(incidence);
     }
 }
@@ -1330,7 +1330,7 @@ void Calendar::notifyIncidenceDeletedOld(const Incidence::Ptr &incidence)
         return;
     }
 
-    foreach (CalendarObserver *observer, d->mObservers) {
+    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
         observer->calendarIncidenceDeleted(incidence);
     }
 }
@@ -1345,7 +1345,7 @@ void Calendar::notifyIncidenceDeleted(const Incidence::Ptr &incidence)
         return;
     }
 
-    foreach (CalendarObserver *observer, d->mObservers) {
+    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
         observer->calendarIncidenceDeleted(incidence, this);
     }
 }
@@ -1360,7 +1360,7 @@ void Calendar::notifyIncidenceAdditionCanceled(const Incidence::Ptr &incidence)
         return;
     }
 
-    foreach (CalendarObserver *observer, d->mObservers) {
+    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
         observer->calendarIncidenceAdditionCanceled(incidence);
     }
 }
